@@ -275,15 +275,15 @@ CHORDS = {
     "SUS2": [0, 2, 7],
     "7SUS": [0, 5, 7],
     "7SUS2": [0, 2, 7],
-    "MAJ_6": [0, 4, 7, 9],
-    "MAJ_6_NO_5": [0, 4, 9],
-    "MAJ_6_9": [0, 4, 9, 14],
-    "MAJ_9": [0, 4, 7, 14],
+    "MAJ6": [0, 4, 7, 9],
+    "MAJ6_NO_5": [0, 4, 9],
+    "MAJ6_9": [0, 4, 9, 14],
+    "MAJ9": [0, 4, 7, 14],
     "MIN": [0, 3, 7],
     "MIN_NO_5": [0, 3],
-    "MIN_6": [0, 3, 7, 9],
-    "MIN_6_NO_5": [0, 3, 9],
-    "MIN_6_9": [0, 3, 9, 14],
+    "MIN6": [0, 3, 7, 9],
+    "MIN6_NO_5": [0, 3, 9],
+    "MIN6_9": [0, 3, 9, 14],
     "DIM": [0, 3, 6],
     "AUG": [0, 4, 8],
     "MAJ7": [0, 4, 7, 11],
